/*
 * Copyright 2016  Samsung Electronics Co., Ltd
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include <gio/gio.h>

#ifndef NOTIFICATION_SERVICE_H_
#define NOTIFICATION_SERVICE_H_

#ifdef __cplusplus
extern "C" {
#endif

int notification_service_init(int restart_count);
int notification_service_fini(void);

int notification_add_noti(GVariant *parameters, GVariant **reply_body,
		const char *sender, pid_t pid, uid_t uid);
int notification_update_noti(GVariant *parameters, GVariant **reply_body,
		pid_t pid, uid_t uid);
int notification_refresh_noti(GVariant *parameters, GVariant **reply_body, uid_t uid);
int notification_del_noti_single(GVariant *parameters, GVariant **reply_body, uid_t uid);
int notification_del_noti_multiple(GVariant *parameters, GVariant **reply_body, uid_t uid);
int notification_del_noti_by_display_applist(GVariant *parameters, GVariant **reply_body, uid_t uid);
int notification_set_noti_property(GVariant *parameters, GVariant **reply_body, uid_t uid);
int notification_get_noti_property(GVariant *parameters, GVariant **reply_body, uid_t uid);
int notification_get_noti_count(GVariant *parameters, GVariant **reply_body, uid_t uid);
int notification_get_noti_all_count(GVariant *parameters, GVariant **reply_body, uid_t uid);
int notification_update_noti_setting(GVariant *parameters, GVariant **reply_body, uid_t uid);
int notification_update_noti_sys_setting(GVariant *parameters, GVariant **reply_body, uid_t uid);
int notification_load_noti_by_tag(GVariant *parameters, GVariant **reply_body, uid_t uid);
int notification_load_noti_by_priv_id(GVariant *parameters, GVariant **reply_body, uid_t uid);
void notification_load_grouping_list(GDBusMethodInvocation *invocation, GVariant *parameters, uid_t uid);
int notification_load_detail_list(GVariant *parameters, GVariant **reply_body, uid_t uid);
int notification_get_setting_array(GVariant *parameters, GVariant **reply_body, uid_t uid);
int notification_get_setting_by_app_id(GVariant *parameters, GVariant **reply_body, uid_t uid);
int notification_load_system_setting(GVariant *parameters, GVariant **reply_body, uid_t uid);
int notification_add_noti_template(GVariant *parameters, GVariant **reply_body, uid_t uid);
int notification_get_noti_template(GVariant *parameters, GVariant **reply_body, pid_t pid, uid_t uid);
int notification_get_noti_package_template(GVariant *parameters, GVariant **reply_body, uid_t uid);
int notification_get_block_state(GVariant *parameters, GVariant **reply_body, uid_t uid);
int notification_load_dnd_allow_exception(GVariant *parameters, GVariant **reply_body, uid_t uid);
int notification_update_dnd_allow_exception(GVariant *parameters, GVariant **reply_body, uid_t uid);
int notification_send_noti_event(GVariant *parameters, GVariant **reply_body);
int notification_send_noti_event_by_priv_id(GVariant *parameters, GVariant **reply_body);
int notification_check_event_receiver(GVariant *parameters, GVariant **reply_body);
int notification_reset_event_receiver(GVariant *parameters, GVariant **reply_body, const char *sender);
int notification_register_dbus_interface();
int notification_delete_noti_by_app_id(const char *app_id, uid_t uid);

#ifdef __cplusplus
}
#endif

#endif //NOTIFICATION_SERVICE_H_